using DFTK
using MPI

disable_threading()

function run()
    DFTK.reset_timer!(DFTK.timer)
    structure = "HfB2_mp-1994_primitive.cif"  # Downloaded from https://materialsproject.org/materials/mp-1994
    lattice   = load_lattice(structure)
    atoms     = load_atoms(structure)

    atoms = [ElementPsp(el.symbol, psp=load_psp(el.symbol, functional="pbe")) => position
             for (el, position) in atoms]
    model = model_PBE(lattice, atoms; temperature=0.01);

    kgrid = [6, 6, 6]     # k-point grid (Regular Monkhorst-Pack grid)
    Ecut  = 50
    basis = PlaneWaveBasis(model, Ecut; kgrid=kgrid);
    mixing = KerkerMixing()

    scfres = self_consistent_field(basis; tol=1e-8, mixing=mixing)
    mpi_master() && println(DFTK.timer)
    MPI.Barrier(MPI.COMM_WORLD)
end

run()
run()
